@@ -107,6 +107,7 @@ struct zathura_s
     struct
     {
       GdkRGBA highlight_color; /**< Color for highlighting */
+      GdkRGBA highlight_color_fg; /**< Color for highlighting (foreground) */
       GdkRGBA highlight_color_active; /** Color for highlighting */
       GdkRGBA render_loading_bg; /**< Background color for render "Loading..." */
       GdkRGBA render_loading_fg; /**< Foreground color for render "Loading..." */
@@ -343,7 +344,7 @@ bool document_open_synctex(zathura_t* zathura, const char* path, const char* uri
 void document_open_idle(zathura_t* zathura, const char* path,
                         const char* password, int page_number,
                         const char* mode, const char* synctex,
-                        const char* search_string);
+                        const char* bookmark_name, const char *search_string);
 
 /**
  * Save a open file
